
.. _algorithms/cycles:

Cycles
******

Algorithms
----------

The following algorithms are available:

.. automodule:: jgrapht.algorithms.cycles
   :members:

Types
-----

Cycles are usually represented with instances of :py:class:`.GraphPath`.

.. autoclass:: jgrapht.types.GraphPath
   :members:
   :noindex:

